% Example of design with the Incoherence via Shifted Power Method
% Uses the corrected version of the algorithm appeared in IEEE SPL, vol.24, Sept.2017
% "Designing Incoherent Frames With Only MatrixVector Multiplications"

m = 20;
n = 120;     % frame size
K = 5000;    % number of iterations
mu = 0.264;  % target coherence; start with large values and decrease gradually
             % if too small, the algorithm does not converge
             % for example, with mu=0.264 convergence is only sometimes obtained;
             % with mu=0.265 almost always
alpha = 0.5; % this trade-off coefficient is important; it should take values between 0.5 and 0.9
             % larger values give slower but safer convergence

% call design function
[F, coh] = ISPM_cor(m, n, mu, alpha, K);

% results
max(max(abs(F'*F - eye(n)))) % check result
plot(coh)                    % plot evolution of mutual coherence    
